km3pipe
=======

Extemporary analysis framework for KM3NeT

Read the docs at http://km3pipe.readthedocs.org

.. image:: https://travis-ci.org/tamasgal/km3pipe.svg?branch=develop
    :target: https://travis-ci.org/tamasgal/km3pipe

.. image:: https://img.shields.io/badge/docs-latest-brightgreen.svg?style=flat
    :target: http://km3pipe.readthedocs.org/en/latest/
